@@ -23,5 +23,4 @@ LPC (Low-Pin Count) is a protocol for low-bandwidth devices used on
 some PC mainboards, such as the "BIOS chip" or the so-called "Super I/O".
 '''
 
-from .pd import *
-
+from .pd import Decoder
